# Simple 2D Frame
# Just to start checking on my 2D IDA concepts for frames
#
# Created 30/Nov/2011 by D. Vamvatsikos
#
wipe

source ../util/generate2DFrameNodes.tcl
source ../util/GetPeriodSetDamping.tcl
source ../util/units_constants_metric.tcl
source ../util/RunGravityAnalysis.tcl


model basic -ndm 2 -ndf 3




#------------------------------------------------------------------------
# default analysis!
#set analysistype "eigenvalue"
#set analysistype "pushover"
set analysistype "dynamic"
#---------------------------
# Pushover load pattern is a*x^k, where x is height from ground and a is a normalizing constant
# if k=0 you get a uniform. If k=1 you get a linear pattern etc.
set pushoverLPk 2.0
#------------------------------------------------------------------------
# Frame geometry
set nbayx 2
set nstory 8
set sheight [expr 3.3*$m]
set baylength [expr 6.0*$m]
# Offset for node and column numbers for every successive story. This allows for almost 100 bays
set csx 100
# Offset for beam numbering. This allows for nearly 100 floors :))
set Beoff 10000


#------------------------------------------------------------------------
# Source the optimization parameters for the bridge (e.g. number of spans)
# The standard file recreates the original Kavala in 2D
if {[file exists "MatIDA_paramfile.tcl"]} {
   puts "Using EXTERNAL parameter file for optimization (Matlab-generated)"
   source MatIDA_paramfile.tcl
} else {
   puts "Using STANDARD parameter file"
   source standard_paramfile.tcl
}

#---------------------------------------------------------------------------
# Source the analysistype information. Better to have it in a distinct file.
if {[file exists "MatIDA_anlsfile.tcl"]} {
   puts "Reading EXTERNAL Analysistype file (Matlab-generated)"
   source MatIDA_anlsfile.tcl
}


#---------------------------
# Source the timehistory information to apply. The default
# file applies "HDA255.AT2.txt" and "HDA165.AT2.txt", upscaled by 7.5
# if another exists, then it is treated as if generated to run an IDA.
if {$analysistype=="dynamic" & [file exists "MatIDA_thfile.tcl"]} {
   set runIDAflag 1
   puts "Using EXTERNAL Timehistory data-file (Matlab-generated)"
   source MatIDA_thfile.tcl
} else {
   set runIDAflag 0
   puts "Using STANDARD Timehistory data-file"
   source standard_thfile.tcl
}
#--------------------------------
# max allowed subdivisions of dt (for variable transient) or standard subdivisions (for Transient)
set dtsub 1.0

# the equalDOFs seriously reduce the eigenmodes that can be calculated.
# Estimate up to 3 eigenvalues. It may fail for only one story. Careful.
if {$nstory<3} {
  set Neigen $nstory  
} else {
  set Neigen 3 	
}


#-----------------------------------------------------------------------------
# 30cm x 30cm RC columns
set Ac [expr 0.30*0.30*$m2]
set Ec [expr 30*$GPa]
set Izzc [expr pow(0.3,4)/12 *$m4]
#-----------------------------------
# 30cm x 60cm RC beams
set Ab [expr 0.30*0.60*$m2]
set Eb [expr 30*$GPa]
set Izzb [expr 0.3*pow(0.6,3)/12 *$m4]
#______________________
# Beam hinge properties
#______________________
# Note: The My is the same for spring and beam. All forces and moments are the same
# for springs in series. Still, adiv (according to Ibarra's Thesis) adjusts the spring
# stiffness, so it has to adjust the spring yield rotation as well (it is reduced by adiv)
# see Figure B.1 of Ibarra's thesis. Thus all the parameters of the backbone that are
# stiffness or ductility related have to change (ah,ac,mc). Those that are force related
# remain the same (My, rf).
set adiv 10
# Hardening ah
set ah 0.03
set ahs [expr ($adiv+1)*$ah/($adiv+1-$adiv*$ah)]
# beam stiffness in double curvature bending
set Kr [expr 0.02*($adiv+1)*6*$Eb*$Izzb/$baylength]
# Yield moment. Originally 4e3. Where did I find this????
set My 1e3


# NOTE: Do not try with ah==0.0, as OpenSees will fail. It will accept a negative
# ah though. Anything as long as it is not zero!
# the slope of the hardening segment is a*E, where a=(Hiso+Hkin)/(E+Hiso+Hkin)
# in our case, use Hiso=0, E=1, so a=Hkin/(E+Hkin) <=> Hkin=a*E/(1-a)
#uniaxialMaterial Hardening $matTag $E $sigmaY $H_iso $H_kin <$eta>
puts "kinematic hardening, ah=$ah, ahs=$ahs "
set Hkin [expr $ahs*$Kr/(1-$ahs)]
set Hiso 0.0
uniaxialMaterial Hardening 1 $Kr $My $Hiso $Hkin


#section Uniaxial $secTag $matTag $string
section Uniaxial 1 1 Mz
# this is great for 3D structures. It will provide UNCOUPLED springs for both bending rotations of
# the beam end.
#section Aggregator 1 1 Mz 1 My 
# for beams
geomTransf Linear 1
# for columns
geomTransf PDelta 2
 


generate2DFrameNodes $nbayx $nstory "{$baylength}" "{$sheight}" $csx


# Generate column elements
for {set i 0} {$i<=$nstory-1} {incr i} {
  for {set j 0} {$j<=$nbayx} {incr j} {
    #element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iz $transfTag
    element elasticBeamColumn [expr $i*$csx+$j+1]  [expr $i*$csx+$j+1] [expr ($i+1)*$csx+$j+1]\
        $Ac $Ec $Izzc 2
  }
}

puts [expr 12*$Eb*($adiv+1)/$adiv*$Izzb/6]

# Generate beam elements
# and place rigid diaphragms!
for {set i 1} {$i<=$nstory} {incr i} {
  for {set j 0} {$j<=$nbayx-1} {incr j} {
     #element beamWithHinges $eleTag $iNode $jNode $secTagI $HingeLengthI $secTagJ $HingeLengthJ $E $A $Iz $transfTag <-mass $massDens> <-iter $maxIters $tol>
     # since the column section is 0.30m deep, I assign 0.30m/6m as the ratio in both ends.
     # the hinge will be formed in the middle, which is about the start of the beam at the column
     # face. This is not superbly accurate though. 
     element beamWithHinges [expr $Beoff+$i*$csx+$j+1]  [expr $i*$csx+$j+1] [expr $i*$csx+$j+2]\
          1 [expr 0.30/$baylength] 1 [expr 0.30/$baylength]\
	  $Eb $Ab [expr ($adiv+1)/$adiv*$Izzb] 1 -iter 5
    # the leftmost node of each beam-line is the master node for the whole story.
    # NEVER slave a node that has been previously used as the master node for another slaving command
    # as this will generate huge analysis errors.
    equalDOF [expr $i*$csx+0+1] [expr $i*$csx+$j+2] 1
  }
}

# Fix to ground
for {set j 0} {$j<=$nbayx} {incr j} {
  fix [expr $j+1] 1 1 1
}




#_______________________
# MASSES AND LOADS
#_______________________

set nmassx [expr 2.0*$ton]
# assign masses
for {set i 1} {$i<=$nstory} {incr i} {
  for {set j 0} {$j<=$nbayx} {incr j} {
    #mass $nodeID $massx $massy $massRot
    mass [expr $i*$csx+$j+1] $nmassx 0 0
  }
}


# assign gravity loads

set nload [expr $nmassx*$g]
pattern Plain 1 Linear {
  for {set i 1} {$i<=$nstory} {incr i} {
    for {set j 0} {$j<=$nbayx} {incr j} {
      #mass $nodeID $massx $massy $massRot
      load [expr $i*$csx+$j+1] 0 [expr -$nload] 0
    }
  }
}


#_______________________
# ANALYSES
#_______________________

constraints Transformation
RunGravityAnalysis 10

# Compute $Neigen modes and apply 2% damping at 1st and 2nd modes 
GetPeriodSetDamping $Neigen 0.02 1 2 "simple2DframePeriods.out"

for {set i 1} {$i<=$nstory} {incr i} {
  # recorder Drift $fileName <-time> $node1 $node2 $dof $perpDirn
  # Interstory drifts. The dof is along x (1) and the height along y (2)
  # NOTE: The higher node should always be second (node 2). I believe the drift is determined as
  #  (node2x-node1x)/abs(node2y-node1y)
  if {$i<10} {
    # use $i\x.out because $ix.out will search for variable $ix not $i.
    recorder Drift -file "idr_0$i\x.out" -time -iNode [expr ($i-1)*$csx+0+1] -jNode [expr $i*$csx+0+1] -dof 1 -perpDirn 2
  } else {
    recorder Drift -file "idr_$i\x.out" -time -iNode [expr ($i-1)*$csx+0+1] -jNode  [expr $i*$csx+0+1] -dof 1 -perpDirn 2
  }
}
# roof drift. The dof is along x (1) and the height along y (2)
recorder Drift -file "roofdrx.out" -time -iNode 1 -jNode [expr $nstory*$csx+0+1] -dof 1 -perpDirn 2


# Now allow option to perform either SPO or single dynamic analysis
if {$analysistype=="pushover"} {
  source ../util/RunPushover2Converge.tcl
  pattern Plain 2 Linear {
    set allsum 0.0
    for {set i 1} {$i<=$nstory} {incr i} {
      set allsum [expr $allsum+pow($i,$pushoverLPk)]
    }
    for {set i 1} {$i<=$nstory} {incr i} {
      load [expr $i*$csx+0+1] [expr pow($i,$pushoverLPk)/$allsum] 0 0 0 0 0
    }
  }
  #integrator DisplacementControl $nodeTag $dofTag $dU1 <$Jd $minDu $maxDu>
  # 1st step is 0.1% roof drift
  set IDctrlNode [expr $nstory*$csx+0+1]
  set DriftStep 0.5e-4
  set DispStep [expr $nstory*$sheight*$DriftStep]
  #set Nsteps 894; # for k=1
  set Nsteps 6000
  set DmaxPush [expr $Nsteps*$DispStep]
  puts "Pushing to [expr $Nsteps*$DriftStep*100]% roof drift in $Nsteps steps"
  integrator DisplacementControl $IDctrlNode 1 $DispStep
  #test EnergyIncr 1.0e-5 10 0
  test NormDispIncr 1.0e-8 20 0
  analysis Static
  RunPushover2Converge  $IDctrlNode $DmaxPush $Nsteps
  loadConst -time 0.0
} elseif {$analysistype=="dynamic"} {
  source ../util/ReadSMDFile3.tcl
  source ../util/RunTransient2Converge.tcl
  source ../util/DefineXYZ_UniformExcitation.tcl

  # you are getting back "nptsx" and "dtx"
  DefineXYZ_UniformExcitation $dtsub $g $GMdir $GMfileX $GMfileY $GMfileZ $GMfactorX $GMfactorY $GMfactorZ nptsx dtx

  integrator Newmark 0.5 0.25
  test NormDispIncr 1.0e-8 10 0
  
  
  analysis Transient
  puts "analysis Transient"
  RunTransient2Converge [expr $nptsx*$dtsub] [expr $dtx/$dtsub]
}


if {!$runIDAflag} {
  # Delete old file as "print" simply appends the new results
  file delete simple2DframePrint.out 
  print simple2DframePrint.out
}
