function runIDA_simplest2Dframe(anlsdir,recorddir,nbayx,nstory)
% runIDA_simplest2Dframe(anlsdir,recorddir,nbayx,nstory)
%
% Runs IDA analysis for a preselected suite of records on 
% generate_simplest2Dframe.tcl by OpenSEES dynamic analyses. It always runs 
% 6 California recordings, XY components (total of 12 records)
%________________________________________________________
% INPUT
%   anlsdir : Where the opensees model ".tcl" file resides. It should be 
%             configured so that when invoked from within that directory it
%             will run flawlessly
%  recorddir: Where the records used for analyzing the model ".tcl" file reside.
%             Note that my routines will generally apply a small
%             modification, moving their 4-line header (PEER style) to the
%             tail.
%  nbayx    : Number of bays in x-direction
%  nstory   : Number of stories
% OUTPUT
%   None, but it saves a lot in files.
%________________________________________________________
% NOTE: anls.savefilename is considered relative to anls.anlsdir
% EXAMPLE: 
% % Try 8-story frame with 2 bays
% % Careful with the slashes! Always used forward slashes (even in Windows
% % PC systems) as Tcl will eat them up "c:\users\..."
% % Please replace the following two directories with the proper ones that
% % you used when installing bundle_runIDA
% recorddir='c:/users/divamva/PSHA/bundle_runIDA/osees/records';
% anlsdir  ='c:/users/divamva/PSHA/bundle_runIDA/osees/simplest2Dframe';
% runIDA_simplest2Dframe(anlsdir,recorddir,2,12);
%
%_________________________________________________________________________
%
% Created 26/Nov/2011, Copyright (c) 2008 by D.Vamvatsikos
%         Used runIDA_ATC62_simpleSDOF_sp2.m as a template
% 
% 

if nargin<4; nstory=8; end
if nargin<3; nbayx=2; end
% You can customize this to provide your own default directories after
% installation.
if nargin<2; error('need at least recorddir/anlsdir inputs'); end



anls.thfilename={'PEL090.AT2','PEL180.AT2','BLD090.AT2','BLD360.AT2'...
            'HDA165.AT2','HDA255.AT2','WAH000.AT2','WAH090.AT2',... 
            'AND270.AT2','AND360.AT2','CLD195.AT2','CLD285.AT2'};


% scale by the first period, which appears in X-direction.
anls.iscaleT=1;
anls.comp=[3,0,0]; % X component only, Sa(T1) is calculated for X-dir
anls.rectype='silva';
% this is the default damping used for estimating Sa(T1). Leave it at 5%
% despite of your model's damping. The reason is that hazard curves almost
% always come out for Sa(T,5%).
anls.def_zeta=0.05;


% OBSERVE How I use Unix standard slashes. This is compatible with TCL and Opensees
% and matlab does not complain.
% NOTE: it is best if you also include the drive letter!
anls.recorddir=recorddir;
anls.anlsdir=anlsdir;
anls.infile='generate_simplest2Dframe.tcl';
% This is the directory where the output is stored.
anls.outdir='./';
% use the openSees executable residing in the parent directory of anlsdir!
anls.exefile='../openSees';
anls.blackbox_anlsproc='anlsproc_oseesNDi';
anls.blackbox_postproc='postproc_osees2Di_frame';
% extra input passed to postproc. Must be a cell array containing all the values that
% will be passed. Note that when calling postproc, the argument is <anls.postproc_input{:}>
% to create a comma-separated list of values. This is not used for SDOF
% analysis but it is very useful e.g. for bridges as it may be used to
% decide what is the main EDP reported back to traceIDA to guide the
% running of the IDA. For example, for a bridge this could be pier drift or
% deck displacement. For frames the best is usually max interstory drift,
% so there is not much of a choice. Of course, your postprocessing routine
% should be customized to achieve this.
anls.postproc_input={};  

% Read a bit in traceIDA to understand what all these mean.
% Under these settings it will perform 8 runs per record up to a maximum Sa
% of 4.95g. This is a "happy" structure that never fails so the IDAs will
% be fairly simple.
trace.maxrpr=8;
trace.iniSa=0.1; 
trace.incSa=0.2; 
% Set a happy 10% drift limit. Stop the analysis if you exceed that.  
% Very useful if your structure never experiences collapse
trace.Th_drift=0.10; 
% max allowable Sa is 50g
trace.Th_Sa=50; 
trace.mode=[2 0];
% demand high resolution if an Inf or Th_drift are reached (1/20!)
trace.hf=[20,6,20]; 
trace.eSa=0.05;
trace.edr=0;


% prepare the parameter file for running. Lengths are in meters
write_MatIDA_paramfile(anls.anlsdir,'MatIDA_paramfile.tcl',0,...
                    'nbayx',nbayx,'nstory',nstory,'sheight','[expr 3.3*$m]',...
                    'baylength','[expr 6.0*$m]');
   
anls.savefilename=sprintf('2Dframe_12recs_%dx%d.sida.mat',nstory,nbayx);

if exist(fullfile(anls.anlsdir,anls.savefilename),'file')
   fprintf('Savefile %s already exists. Aborting\n',anls.savefilename)
else
   %%% USE FOR SINGLE CPU
   [svalues,dvalues,anlsout,T_periods,runs,record_saxy,record_pgaxy]=runIDA_ND(anls,trace);
   % no need to save the output. This is already done. I am just
   % supplying these output vars in case you need to do something with
   % them here.
end